@@ -7,12 +7,11 @@
 #'  \item \code{get_dates}: get dates of the predictions.
 #'
 #' }
-#'
+#' @name get_dates
 #' @rdname projections_accessors
 #'
 #' @author Thibaut Jombart \email{thibautjombart@@gmail.com}
 #'
-#' @export
 #'
 #' @param x A \code{projections} object.
 #'
@@ -21,7 +20,7 @@
 #' @examples
 #'
 #'
-#' if (require(distcrete) && require(incidence)) {
+#' if (require(distcrete) && require(incidence)) { withAutoprint({
 #'
 #' ## prepare input: epicurve and serial interval
 #' dat <- c(0, 2, 2, 3, 3, 5, 5, 5, 6, 6, 6, 6)
@@ -40,28 +39,12 @@
 #' get_dates(pred_1)
 #' max(i$dates) # predictions start 1 day after last incidence
 #'
-#' }
-#'
-
-get_dates <- function(x, ...) {
-    UseMethod("get_dates", x)
-}
-
-
-#' @rdname projections_accessors
-#' @export
-#' @aliases get_dates.default
-
-get_dates.default <- function(x, ...) {
-    stop(sprintf("Not implemented for class %s",
-                 paste(class(x), collapse = ", ")))
-}
-
-
-#' @rdname projections_accessors
-#' @export
+#' })}
 #' @aliases get_dates.projections
-
+#' @aliases get_dates
+#' @importFrom incidence get_dates
+#' @export get_dates
+#' @export
 get_dates.projections <- function(x, ...) {
     attr(x, "dates")
 }
